##  Dashboards with Predefined KPIs
The following predefined dashboards include KPI panels:
  * Application Portfolio Management Dashboard
  * Application Rationalization Dashboard
  * Obsolescence Risk Dashboard


You can view these dashboards to see examples of how KPIs are used to track key metrics.
